import { Coin, AccountMap, TransactionMap, SubscriptionResponse, ErrorResponse, SuccessResponse } from "frontblock-generic/Types";
import { FrontblockApi as FrontblockApi } from "frontblock-generic/Api";
import { Plugin, socketioRPC } from "frontblock-generic/Plugin";
export declare type FrontblockApiConf = {
    apiHost: string;
    apiPort: number;
    tls?: boolean;
    apiKey?: string;
};
/**
 * Frontblock api connection lib
 *
 * Can be used solo and also is a valid frontblock plugin on the customer-side
 */
export default class FrontblockApiClient implements FrontblockApi, Plugin {
    name: string;
    protected apikey: string;
    protected conf: FrontblockApiConf;
    protected socket: any;
    private started;
    constructor(conf?: FrontblockApiConf);
    exportRPCs(): socketioRPC[];
    start(): void;
    stop(): void;
    consume<C extends Coin>(apikey: string, uid: string, callback: (tx: TransactionMap[C]) => void): Promise<SubscriptionResponse | ErrorResponse>;
    quit(apikey: string, consumerUid: string): Promise<ErrorResponse | SuccessResponse>;
    subscribe<C extends Coin>(apikey: string, coin: C, account: AccountMap[C]): Promise<SubscriptionResponse | ErrorResponse>;
    subsume<C extends Coin>(apikey: string, coin: C, account: AccountMap[C], callback: (tx: TransactionMap[C]) => void): Promise<SubscriptionResponse | ErrorResponse>;
    unsubscribe(apikey: string, uid: string): Promise<ErrorResponse | SuccessResponse>;
    getPluginList(): Promise<string[]>;
}
